/*
 * key-engine.h -- shared definitions and prototypes
 *
 * Copyright (c) 2000 Alessandro Rubini (rubini@gnu.org)
 * Sponsored by Linuxcare Italia Spa.
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __KEY_ENGINE_H__
#define __KEY_ENGINE_H__

/* All of these should better be parametrized */
#define KE_FBDEV "/dev/fb0"
#define KE_TPDEV    "/dev/tpanel"
#define KE_CALIB_DATA "/etc/pointercal"
#define KE_KEYB_LIST  "/etc/kbig2.list"

#define STRINGNAME_LEN 24
#define STRINGEXP_LEN 24

#define SPECIAL_SHIFT    1
#define SPECIAL_CONTROL  2
#define SPECIAL_META     4
#define SPECIAL_FUNCTION 8
#define SPECIAL_CAPS    16

typedef struct {
  int width;
  int height;
  int depth;
  int linelen;
  unsigned long size;
  unsigned char *addr;
  unsigned char *offscreenkeymap;
} fbinfo, *fbinfoptr;

struct string {
    char name[STRINGNAME_LEN];
    char expand[STRINGEXP_LEN];
    int explen;
};

struct keydef {
    int x[4], y[4];
    int codes[2]; /* non-shifted, shifted */
    struct string *sptr;
    int special;
};

extern char *prgname;

/* key-parse.c */
extern int kparse_parse_file(char *fname, FILE *ef, char *ehead);
extern int kparse_usestroke(int coords[4], char *result, int *rlen, fbinfo *devinfo);

/* key-draw.c */
extern int kdraw_xor(unsigned char *buf, int *x, int *y, fbinfo *devinfo);
extern void kdraw_redraw(void);
extern int kdraw_init(char *fbfile, fbinfo *devinfo);
extern int key_draw_rect(char *offscreenkeymap, fbinfo *devinfo, 
			 int xi, int yi, int xe, int ye, int mode);
extern int key_draw_string(char *offscreenkeymap, fbinfo *devinfo,
			   char *s,
			   int xi, int yi, int xe, int ye);
extern int key_draw_char(char *offscreenkeymap, fbinfo *devinfo, 
			 int c,
			 int xi, int yi, int xe, int ye);
void draw_keyboard(fbinfo *devinfo);

/* key-panel.c */
extern int kpanel_init(char *tpfile, char *tpdev);
extern int kpanel_read(int fd, int *x, int *y, int *z, int *down);
extern int kpanel_getstroke(int coords[4]);

#include "mwin.h"

#endif


