/*
 * key-main.c -- trivial main procedure for the key-engine
 *
 * Copyright (c) 2000 Alessandro Rubini (rubini@gnu.org)
 * Sponsored by Linuxcare Italia Spa.
 *
 * Extensive modifications by Jorj Bauer <jorj@seas.upenn.edu>,
 * sponsored by DejaVu Software, Inc. (http://www.dejavusoftware.com/).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <ctype.h>
#include <errno.h>
#include <fcntl.h>
#include <sys/mman.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <sys/ioctl.h>
#include <linux/types.h>
#include <linux/vt.h>

#include "key-engine.h"

char *prgname;

int main(int argc, char **argv)
{
    int coords[4];
    char data[16];
    int dlen, fd;
    fbinfo devinfo;

    prgname = argv[0];
    if (getuid()!=0) {
	fprintf(stderr, "%s: need to run as root\n", argv[0]);
	exit(1);
    }
    if (kpanel_init(KE_CALIB_DATA, KE_TPDEV))
	exit(1);

    /* initialize the key list */
    kparse_parse_file(KE_KEYB_LIST, stderr, "key-engine: ");
    
    /* initialize drawing */
    kdraw_init(KE_FBDEV, &devinfo);

    /* get keys and push them to /dev/tty0, forever */
    while (1) {
	int i;
	char unblank = 4; /* TIOCLINUX command */

	kdraw_redraw();
	kpanel_getstroke(coords);
	kdraw_redraw();
#if 0 /* this can be piped to "testtool", to check stroke decoding */
	printf("%i %i %i %i\n", coords[0], coords[1], coords[2], coords[3]);
	fflush(stdout);
	continue;
#endif
	kparse_usestroke(coords, data, &dlen, &devinfo);
	kdraw_redraw();

	if (dlen == -1) {/* special: console switch required */
	    int consolenr = data[0];
	    printf("switching to console %i\n", consolenr);
	    fd = open("/dev/tty0",O_RDONLY);
	    ioctl(fd, VT_ACTIVATE, consolenr);
	    close(fd);
	    continue;
	}
	if (!dlen) continue; /* avoid opening etc if nothing to poke */
	fd = open("/dev/tty0",O_WRONLY);
	ioctl(fd, TIOCLINUX, &unblank);
	for (i=0; i<dlen; i++) {
	  ioctl(fd,TIOCSTI,data+i);
	}
	close(fd);
    }
    return 0;
}
